@@ -89,7 +89,7 @@ gnome_vfs_volume_monitor_daemon_get_type (void)
 	static GType volume_monitor_daemon_type = 0;
 
 	if (!volume_monitor_daemon_type) {
-		static const GTypeInfo volume_monitor_daemon_info = {
+		const GTypeInfo volume_monitor_daemon_info = {
 			sizeof (GnomeVFSVolumeMonitorDaemonClass),
 			NULL,		/* base_init */
 			NULL,		/* base_finalize */
@@ -629,7 +629,10 @@ get_drive_name (GnomeVFSVolumeMonitor *volume_monitor,
 	utf8_name = make_utf8 (name);
 	g_free (name);
 	
-	return _gnome_vfs_volume_monitor_uniquify_drive_name (volume_monitor, utf8_name);
+	name = _gnome_vfs_volume_monitor_uniquify_drive_name (volume_monitor, utf8_name);
+	g_free (utf8_name);
+
+	return name;
 }
 
 
